@@ -22,6 +22,7 @@ import os
 import logging
 import pickle
 import codecs
+from pathlib import Path
 
 class Context(Dict):
     __context_variable_name = "github_action_context_variable_holder"
@@ -37,10 +38,14 @@ class Context(Dict):
             logging.debug("Environment context not found. Initializing to empty.")
             logging.debug(f"All env variables: {os.environ}")
             self.update(globals().get(self.__context_variable_name))
-        elif os.getenv('github_context_variable_holder') is not None:
+        elif os.getenv(self.__context_variable_name) is not None:
             self.rehydrate(os.getenv(self.__context_variable_name))
-            logging.debug("CONTEXT environment variable found.")
-            logging.debug(f"CONTEXT == {self}")
+            logging.debug(f"'{self.__context_variable_name}' environment variable found.")
+            logging.debug(f"'{self.__context_variable_name}' == {self}")
+        elif Path(self.__context_variable_name).exists():
+            logging.debug("File found - reading values.")
+            file_text = Path(self.__context_variable_name).read_text()
+            self.rehydrate(file_text)
         else:
             logging.debug("Environment context not found. Initializing to empty.")
             logging.debug(f"All env variables: {os.environ}")
@@ -80,6 +85,7 @@ class Context(Dict):
             print(f'::set-output name={self.__context_variable_name}::{context_serialization}')
 
         os.environ[self.__context_variable_name] = context_serialization
+        Path(self.__context_variable_name).write_text(context_serialization)
 
     def print_context(self):
         print(self)
